@@ -1,9 +1,20 @@
 from colab_ssh.launch_ssh import launch_ssh
-from colab_ssh.init_git import init_git
+from colab_ssh.init_git import init_git, init_git_cloudflared
 
 from colab_ssh._command import run_command, run_with_pipe
 from colab_ssh.launch_direct_ssh import launch_direct_ssh
 from colab_ssh.set_private_key import set_private_key
 from colab_ssh.get_tunnel_config import get_tunnel_config
 from colab_ssh.launch_ssh_cloudflared import launch_ssh_cloudflared
-from colab_ssh.init_git_cloudflared import init_git_cloudflared
\ No newline at end of file
+
+__all__ = [
+    "launch_ssh",
+    "init_git",
+    "init_git_cloudflared",
+    "run_command",
+    "run_with_pipe",
+    "launch_direct_ssh",
+    "set_private_key",
+    "get_tunnel_config",
+    "launch_ssh_cloudflared",
+]
\ No newline at end of file
